import fs from 'fs-extra';
import axios from 'axios';
import { fileTypeFromBuffer } from 'file-type';
import { execSync } from 'child_process';

// src/util/dateTime.ts
var createDate = (hours, minutes) => {
  const date = /* @__PURE__ */ new Date();
  date.setHours(hours, minutes, 0, 0);
  return date;
};
var MS_PER_DAY = 1e3 * 60 * 60 * 24;
var createDateFromNowWithOffset = (offsetInDays) => {
  const currentDate = /* @__PURE__ */ new Date();
  const offsetInMilliseconds = offsetInDays * MS_PER_DAY;
  const newDate = new Date(currentDate.getTime() + offsetInMilliseconds);
  return newDate;
};
var fsDeleteDirectory = async (directoryPath) => {
  if (!fs.existsSync(directoryPath))
    return true;
  await fs.rm(directoryPath, { recursive: true, force: true });
  return true;
};
var fsDeleteFile = async (filePath) => fs.promises.rm(filePath, { force: true }).then(
  () => true,
  () => true
);
var { writeFile, ensureDir } = fs;
var writeToFile = async (directory, content, fileName) => {
  await ensureDir(directory);
  const filePath = `${directory}/${fileName}`;
  await writeFile(filePath, content);
  return filePath;
};

// src/convert/bytesToMb.ts
var bytesToMb = (bytes) => Math.round(bytes / 1024 / 1024);

// src/convert/epochToDate.ts
var epochToDate = (epoch) => new Date(Number(epoch) * 1e3);

// src/util/fs/fsDownloadFromUrl.ts
var downloadFileFromUrl = async ({
  url,
  fileName,
  directoryPath,
  limit
}) => new Promise(async (resolve, reject) => {
  if (!url || !directoryPath) {
    return reject("Url and DirectoryPath are required");
  }
  const fileLimit = {
    minBytes: 0,
    maxBytes: 100 * 1024 * 1024,
    // 100 MB
    ...limit
  };
  try {
    const { data, headers } = await axios.get(url, {
      responseType: "arraybuffer",
      maxBodyLength: fileLimit.maxBytes
    });
    const contentLength = parseInt(
      headers["content-length"] ?? "0",
      10
    );
    if (isNaN(contentLength) || contentLength <= 0 || contentLength > fileLimit.maxBytes || contentLength < fileLimit.minBytes) {
      return reject(
        `Media size is invalid. Size should be between ${fileLimit.maxBytes} and ${fileLimit.minBytes} bytes or between ${bytesToMb(
          fileLimit.maxBytes
        )} and ${bytesToMb(fileLimit.minBytes)}`
      );
    }
    const fileType = await fileTypeFromBuffer(data);
    if (!fileType || !isValidMediaType(fileType.mime)) {
      return reject("Invalid media type. Should be image, video, pdf or doc");
    }
    const fileNameString = fileName ?? `${Date.now()}-${Math.random()}.${fileType.ext}`;
    const filePath = await writeToFile(
      directoryPath,
      data,
      fileNameString
    );
    const fileData = {
      path: filePath,
      size: contentLength,
      sizeInMB: `${(contentLength / 1024 / 1024).toFixed(2)} MB`,
      fileType: fileType.mime,
      fileTypeExt: fileType.ext,
      fileName: fileNameString,
      url,
      createdAt: /* @__PURE__ */ new Date()
    };
    resolve(fileData);
  } catch (error) {
    return reject(error);
  }
});
var isValidMediaType = (mediaType) => {
  return mediaType.startsWith("image/") || mediaType.startsWith("video/") || mediaType.startsWith("audio/") || mediaType.startsWith("application/pdf") || mediaType.startsWith("application/msword") || mediaType.startsWith(
    "application/vnd.openxmlformats-officedocument.wordprocessingml.document"
  );
};
var { writeJson: writeJsonFile } = fs;
var readJSONFile = async (filePath) => {
  const fileContent = await fs.readFile(filePath, "utf8");
  try {
    return JSON.parse(fileContent);
  } catch (error) {
    throw error;
  }
};
var writeJsonToFile = async (filePath, jsonData, options) => {
  if (typeof filePath !== "string" || filePath.length === 0) {
    throw new Error("Invalid filePath");
  }
  if (jsonData === null || jsonData === void 0) {
    throw new Error("Invalid jsonData");
  }
  let data;
  if (typeof jsonData === "string") {
    try {
      data = JSON.parse(jsonData);
    } catch (err) {
      throw new Error("Invalid jsonData");
    }
  } else {
    data = jsonData;
  }
  try {
    await writeJsonFile(filePath, data, options);
    return true;
  } catch (error) {
    throw new Error(
      `Failed to write JSON file: ${filePath}, error: ${error.message}`
    );
  }
};
var readFile = async (filePath) => new Promise(async (resolve, reject) => {
  const f = fs.readFileSync(filePath);
  resolve(f);
});
var getFile = async (filePath) => {
  return await readFile(filePath);
};

// src/util/randomStringOfLength.ts
var randomStringOfLength = (length) => {
  if (typeof length !== "number" || length < 0) {
    throw new Error("Length must be a non-negative integer");
  }
  const chars = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";
  let result = "";
  for (let i = length; i > 0; i--) {
    const randomIndex = Math.floor(Math.random() * chars.length);
    if (randomIndex >= 0 && randomIndex < chars.length) {
      result += chars[randomIndex];
    } else {
      throw new Error("Invalid random index");
    }
  }
  return result;
};

// src/util/generateRandomNumberBetween.ts
var generateRandomNumberBetween = (min, max) => {
  if (typeof min !== "number") {
    throw new TypeError("Min must be a number");
  }
  if (typeof max !== "number") {
    throw new TypeError("Max must be a number");
  }
  if (min > max) {
    throw new RangeError("Min must be less than or equal to max");
  }
  const range = max - min + 1;
  return Math.floor(Math.random() * range) + min;
};
var genOpensslRand = (length, method = "base64") => {
  if (length <= 0) {
    throw new Error("Length must be a positive number");
  }
  const cmd = `openssl rand -${method} ${length} | tr -d '\\n'`;
  try {
    const key = execSync(cmd).toString();
    if (key === null) {
      throw new Error("OpenSSL command execution failed");
    }
    return key;
  } catch (err) {
    if (err instanceof Error) {
      throw err;
    } else {
      throw new Error("Unknown error occurred");
    }
  }
};

// src/isValid/isValidIpAddress.ts
var isValidIpAddress = (ipAddress) => {
  if (typeof ipAddress !== "string") {
    throw new TypeError("ipAddress must be a string");
  }
  const ipAddressRegex = /^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/;
  return ipAddressRegex.test(ipAddress);
};

// src/isValid/isValidJson.ts
var isValidJson = (json) => {
  try {
    if (typeof json !== "string") {
      return false;
    }
    JSON.parse(json);
  } catch (e) {
    return false;
  }
  return true;
};

// src/isValid/isValidUrl.ts
var defaultAllowed = ["https:", "http:"];
var allowedLocalHosts = ["localhost", "127.0.0.1"];
var isValidUrl = (url, allowedProtocols) => {
  try {
    if (typeof url !== "string") {
      throw new TypeError("url must be a string");
    }
    if (url.length === 0)
      return false;
    if (allowedLocalHosts.includes(url))
      return true;
    if (url.includes(".") && !url.includes("://"))
      return isValidUrl(`http://${url}`);
    const fccUrl = new URL(url);
    const mapProtocols = allowedProtocols?.map((p) => p.endsWith(":") ? p : `${p}:`) ?? [];
    const checkProtocols = [...defaultAllowed, ...mapProtocols].map(
      (p) => p.toLowerCase()
    );
    const check = checkProtocols.includes(fccUrl.protocol) || checkProtocols.includes(fccUrl.protocol.toLowerCase());
    if (check)
      return true;
    return false;
  } catch (error) {
    return false;
  }
};

// src/helpers/getRawFile.ts
var gitHost = "https://raw.githubusercontent.com";
var createGitRawLink = ({
  branch,
  filename,
  repo,
  user,
  gitHost: gh
}) => `${gh ?? gitHost}/${user}/${repo}/${branch}/${filename}`;
var getGitRawFile = async (filePath, parse = false) => {
  try {
    const url = typeof filePath === "string" ? new URL(filePath) : new URL(createGitRawLink(filePath));
    const response = await fetch(url);
    if (!response.ok) {
      throw new Error(
        `Failed to fetch url: ${url}, status: ${response.status}`
      );
    }
    const text = await response.text();
    return parse ? JSON.parse(text) : text;
  } catch (error) {
    throw error;
  }
};

export { bytesToMb, createDate, createDateFromNowWithOffset, createGitRawLink, downloadFileFromUrl, epochToDate, fsDeleteDirectory, fsDeleteFile, getFile as fsGetFile, readFile as fsReadFile, readJSONFile as fsReadJSONFile, writeJsonToFile as fsWriteJsonToFile, writeToFile as fsWriteToFile, genOpensslRand, generateRandomNumberBetween, getGitRawFile, isValidIpAddress, isValidJson, isValidUrl, randomStringOfLength };
//# sourceMappingURL=out.js.map
//# sourceMappingURL=index.js.map